from __future__ import absolute_import
from __future__ import print_function

from enigma import eConsoleAppContainer
from Screens.Screen import Screen
from Components.ActionMap import ActionMap
from Components.ScrollLabel import ScrollLabel
from Components.Slider import Slider
from enigma import eTimer, quitMainloop
from Components.Label import Label

class eConsole(Screen):
    skin = """
        <screen position="center,center" size="600,200" title="Meknes" >
            <widget name="text" position="20,20" size="600,140" font="Console;14" />
            <widget name="activityslider" position="20,170" size="560,10" borderWidth="2" borderColor="#40A497"/>
            <widget name="slider" position="20,170" size="560,20" />
        </screen>"""
    
    def __init__(self, session, title = 'Console', cmdlist = None, finishedCallback = None, closeOnSuccess = False):
        Screen.__init__(self, session)
        self.finishedCallback = finishedCallback
        self.closeOnSuccess = closeOnSuccess
        self.slider = Slider(0, 4)
        self['slider'] = self.slider
        self.activityslider = Slider(0, 100)
        self['activityslider'] = self.activityslider
        self['text'] = ScrollLabel('')
        self['actions'] = ActionMap([
            'WizardActions',
            'DirectionActions'], {
            'ok': self.cancel,
            'back': self.cancel,
            'up': self['text'].pageUp,
            'down': self['text'].pageDown }, -1)
        self.cmdlist = cmdlist
        self.newtitle = title
        self.onShown.append(self.updateTitle)
        self.activity = 0
        self.activityTimer = eTimer()
        self.activityTimer.callback.append(self.doActivityTimer)
        self.container = eConsoleAppContainer()
        self.run = 0
        self.container.appClosed.append(self.runFinished)
        self.container.dataAvail.append(self.dataAvail)
        self.onLayoutFinish.append(self.startRun)

    
    def updateTitle(self):
        self.setTitle(self.newtitle)

    
    def startRun(self):
        self['text'].setText(_("\nPatientez s'il vous plait:") + '\n\n')
        self.activityTimer.start(250, False)
        print ('Console: executing in run', self.run, ' the command:', self.cmdlist[self.run])
        if self.container.execute(self.cmdlist[self.run]):
            self.runFinished(-1)

    
    def runFinished(self, retval):
        self.run += 1
        if self.run != len(self.cmdlist) or self.container.execute(self.cmdlist[self.run]):
            self.runFinished(-1)
        
        str = self['text'].getText()
        str = _('\nEx\xc3\xa9cution termin\xc3\xa9e! Cliquez sur OK pour continuer')
        self.activityTimer.stop()
        self.activityslider.setValue(0)
        self.activityslider.hide()
        self['text'].setText(str)
        self['text'].lastPage()
        if self.finishedCallback is not None:
            self.finishedCallback()
        if not retval and self.closeOnSuccess:
            self.cancel()

    
    def cancel(self):
        if self.run == len(self.cmdlist):
            self.close()
            self.appClosed_conn = None
            self.dataAvail_conn = None

    
    def dataAvail(self, str):
        self['text'].setText(self['text'].getText())

    
    def doActivityTimer(self):
        self.activity += 1
        if self.activity == 100:
            self.activity = 0
        self.activityslider.setValue(self.activity)


